<?php
/*
Plugin Name: Bot Allow Content
Plugin URI: http://www.g-loaded.eu/2006/01/04/bot-allow-content-wordpress-plugin/
Description: If you serve only summaries through your feeds, this plugin allows pre-defined bots to read and index the full content.
Version: 0.6
Author: GNot
Author URI: http://www.g-loaded.eu/

Info:
This plugin assumes that you serve summaries in your feeds, although this setting has no impact on the
plugin's functionality. It allows you to define which bots can index the full content of your posts
through syndicated content. You do not have to supply the full USER_AGENT string of the bots, but just
a part of it. It provides a configuration page within the administration panel.
The path is: Options->Syndication Extra
This plugin is Atom 1.0 friendly. All of you who have hacked the default wp-atopm.php file to conform with
the Atom 1.0 Specifications, make sure you set the option below to TRUE. This configuration option is not
available from within the administration panel for obvious reasons.

Installation:
Copy bot-allow-content.php to your plugins directory and activate it through the administration panel.
Go to Admin Panel->Options->Syndication Extra to configure it.

Atom 1.0 Configuration BEGIN:
If you have modified the default deprecated Atom 0.3 feed to comply with the Atom 1.0
specification, then set the following to TRUE. If you do not know what this is, leave it to FALSE */
$IsAtom1 = TRUE;

/* Configuration END */


/*  Copyright (C) George Notaras (http://www.g-loaded.eu/)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


/* Changelog
* Wed Nov 01 2006 - v0.6
- When the options where modified in the administration panel, a confirmation was asked.
  This behaviour has been corrected and the options are saved immediately.
* Wed Oct 04 2006 - v0.5
- Plugin information update
* Sat Jan 15 2006
- Updated to version 0.4
- Addition: A configuration page has been added in the Admin Panel. No editing of the source code is needed.
- Bugfix: Added a check if the list of bots is empty. The absense of it did not produce any errors though.
* Wed Jan 4 2006
- Updated to version 0.3
- The plugin was completely re-written, so that no modifications are required to be done to core wp files, but supports only WP 2 or newer.
* Tue Jan 3 2006
- Initial release v0.2
*/


// Admin Panel
function bac_add_pages() {
	add_options_page('Syndication Extra Options', 'Syndication Extra', 8, __FILE__, 'bac_options_page');
}


function bac_options_page() {
	if (isset($_POST['info_update'])) {
		if (empty($_POST['bac_allowed_bots'])) {
			// Delete the option from the DB if it's empty
			delete_option('bac_allowed_bots');
			$msg = "Option deleted from the WordPress database.";
		} else {
			$AllowedBots = $_POST['bac_allowed_bots'];
			update_option('bac_allowed_bots', $AllowedBots);
			$msg = "Option saved.";
		}
		_e('<div id="message" class="updated fade"><p>' . $msg . '</p></div>');
	} else {
		$AllowedBots = get_option('bac_allowed_bots');
	}

	// Configuration Page
	_e('
		<div class="wrap">
			<h2>Syndication Extra Configuration</h2>
			<p>This is the configuration page of the <em>Bot-Allow-Content</em> plugin.<br /><br />
			If you serve only summaries of your posts, this is the place where 
			you can define	which bots will be allowed to read and index the full content of your 
			posts through the Atom,	RSS 2.0 and RDF feeds. If you serve full content, then these 
			settings have no effect.
			You do not have to provide the full <code>USER_AGENT</code> string of each bot, 
			but only a distinct part of it.</p>
			<form name="formbac" method="post" action="' . $_SERVER['REQUEST_URI'] . '">
				<fieldset class="options">
					<legend>Allowed Bots<br />
						<small><em>(Provide a comma separated list of bots.)</em></small>
						<p><input name="bac_allowed_bots" type="text" id="bac_allowed_bots" class="code" value="' . $AllowedBots . '" size="80" /></p>
						<p><strong>Example</strong>: <code>Technoratibot, Googlebot, BlogSearch, Feedster</code></p>
						<p><strong>Info</strong>: This plugin stores a new option in the WordPress database.
							By leaving this text box blank and hitting the &quot;<em>Update Options</em>&quot;
							button, the option is removed from the WordPress database. Although it is not 
							necessary, you should consider doing this before uninstalling the plugin, 
							so no trace is left behind.
						</p>
					</legend>
				</fieldset>
				<p class="submit">
					<input type="submit" name="info_update" value="Update Options &raquo;" />
				</p>
			</form>
		</div>
	');
}

add_action('admin_menu', 'bac_add_pages');


function bac_is_bot_allowed() {
	$AllowedBots = get_option('bac_allowed_bots');

	if (!empty($AllowedBots)) {
	    $BotArr = explode(",", $AllowedBots);
	    foreach ($BotArr as $BotString) {
	        if ( strstr($_SERVER['HTTP_USER_AGENT'], trim($BotString)) !== FALSE ) {
				return true;
			}
	    }
	}
	return false;
}


function bac_append_the_content() {
	global $IsAtom1, $feed;

	if ( get_settings('rss_use_excerpt') && bac_is_bot_allowed() ) {
		switch($feed) {
			case 'atom' :
				if ($IsAtom1) {
					echo "\n\t\t<content type=\"xhtml\"><div xmlns=\"http://www.w3.org/1999/xhtml\">";
					the_content('', 0, '');
					echo "</div></content>\n";
				} else {
					echo "\n\t\t<content type=\"";
					bloginfo('html_type');
					echo "\" mode=\"escaped\" xml:base=\"";
					permalink_single_rss();
					echo "\"><![CDATA[";
					the_content('', 0, '');
					echo "]]></content>\n";
				}
				break;
			case 'rss2' :
				echo "\n\t\t<content:encoded><![CDATA[";
				the_content('', 0, '');
				echo "]]></content:encoded>";
				break;
			case 'rdf' :
				echo "\n\t\t<content:encoded><![CDATA[";
				the_content('', 0, '');
				echo "]]></content:encoded>";
				break;
		}
	}
}

add_action('atom_entry', 'bac_append_the_content');
add_action('rss2_item', 'bac_append_the_content');
add_action('rdf_item', 'bac_append_the_content');

?>
